# Changelog

## 0.1.15

- Revamped component schema resolution logic, making it easier and more straightforward to convert from a Component's schema to an instance of the Python class. See the docs on creating a custom component to learn more!
- Added an `@component` decorator, making it possible to instantiate components with pure python code. See the docs on adding a component to a project without yaml to learn more!

## 0.1.11

_Inception of changelog occurs at this point_
